IDropTarget

Struct IDropTarget 

pub struct IDropTarget(/* private fields */);
Available on crate feature ole only.
IDropTarget COM interface.

Automatically calls Release when the object goes out of scope.

Examples

Retrieving dropped files:

use winsafe::{self as w, prelude::*, co};

let drop_target = w::IDropTarget::new_impl();

drop_target.Drop(
    |d: &w::IDataObject, key_st: co::MK, pt: w::POINT, fx: &mut co::DROPEFFECT|
        -> w::AnyResult<()>
    {
        let mut fmt = w::FORMATETC::default();
        fmt.cfFormat = co::CF::HDROP;
        fmt.dwAspect = co::DVASPECT::CONTENT;
        fmt.tymed = co::TYMED::HGLOBAL;

        let medium = unsafe { d.GetData(&fmt)? };
        let hglobal = unsafe { medium.ptr_hglobal().unwrap() };
        let ptr_lock = hglobal.GlobalLock()?;
        let hdrop = unsafe { w::HDROP::from_ptr(ptr_lock.as_ptr() as _) };
        let dropped_paths = hdrop.DragQueryFile()?
            .collect::<w::SysResult<Vec<_>>>()?;

        for f in dropped_paths {
            println!("> {f}");
        }

        Ok(())
    },
);

Implementations

Source

impl IDropTarget

pub fn new_impl() -> Self

Creates a custom COM implementation, to which you can add closures to handle events.

Source

impl IDropTarget

pub fn DragEnter<F>(&self, func: F) -> &Self
where F: Fn(&IDataObject, MK, POINT, &mut DROPEFFECT) -> AnyResult<()> + 'static,

IDropTarget::DragEnter method.

Examples
use winsafe::{self as w, prelude::*, co};

let drop_target = w::IDropTarget::new_impl();

drop_target.DragEnter(
    |d: &w::IDataObject, key_st: co::MK, pt: w::POINT, fx: &mut co::DROPEFFECT|
        -> w::AnyResult<()>
    {
        *fx &= co::DROPEFFECT::COPY;
        Ok(())
    },
);
pub fn DragLeave<F>(&self, func: F) -> &Self
where F: Fn() -> AnyResult<()> + 'static,

pub fn DragOver<F>(&self, func: F) -> &Self
where F: Fn(MK, POINT, &mut DROPEFFECT) -> AnyResult<()> + 'static,

IDropTarget::DragOver method.

Examples
use winsafe::{self as w, prelude::*, co};

let drop_target = w::IDropTarget::new_impl();

drop_target.DragOver(
    |key_st: co::MK, pt: w::POINT, fx: &mut co::DROPEFFECT|
        -> w::AnyResult<()>
    {
        *fx &= co::DROPEFFECT::COPY;
        Ok(())
    },
);
pub fn Drop<F>(&self, func: F) -> &Self
where F: Fn(&IDataObject, MK, POINT, &mut DROPEFFECT) -> AnyResult<()> + 'static,